pub struct WakeSignal { /* private fields */ }Expand description
Signal for waking the consumer when new data is available.
In production this will wrap an eventfd file descriptor.
For testing without io_uring, it uses a simple atomic flag + thread parking.
Implementations
Sourceimpl WakeSignal
impl WakeSignal